;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "company" "20260515.1349"
  "Modular text completion framework."
  '((emacs    "26.1")
    (posframe "1.5.1"))
  :url "http://company-mode.github.io/"
  :commit "4faf36bc250fa6edaf91d11dd4191afd68a3b629"
  :revdesc "4faf36bc250f"
  :keywords '("abbrev" "convenience" "matching")
  :maintainers '(("Dmitry Gutov" . "dmitry@gutov.dev")))
